Models
======


These models are used for argument and return value validation. They are based on the `pydantic <https://pydantic-docs.helpmanual.io/>`_ package.

Definitions
-----------

.. automodule:: avatars.models
   :members:
   :undoc-members:
